# Changelog

All notable changes to this project will be documented in this file.

The format is based on
[Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project
adheres to [Calendar Versioning](https://calver.org/).

## \[22.8.20\] - 2022-08-20

- Fix examples in README and docs index
- Add docs for QONetwork
- Prepare documentation for quantum_oscillator sub-package.

## \[22.6.27\] - 2022-06-27

- Implement neural network for Quantum Oscillator approximation
